@@ -1,4 +1,4 @@
 .onLoad <- function(lib,pkg) {
 	require(methods)
-	cat("FLEDA 1.3-2 - \"The Dutch Comrade\" \n")
+	cat("FLEDA 1.4-2 - \"The Jackal's Associate\" \n")
 }
